@@ -3,7 +3,7 @@
 #
 # unit tests for littletable library
 #
-
+import types
 import unittest
 import littletable as lt
 import itertools
@@ -108,6 +108,7 @@ class TestDataObjects(unittest.TestCase):
 
         self.assertEqual("{'a': 10}", repr(ob2))
 
+
 class TestTableTypes(unittest.TestCase):
     def test_types(self):
         
@@ -185,6 +186,24 @@ class TableCreateTests:
         with self.assertRaises(KeyError):
             table.create_index('a', unique=True)
 
+    def test_insert_dicts(self):
+        table = lt.Table()
+        table.insert({"a": 1, "b": 2, "c": 3})
+        table.insert({"a": 4, "b": 5, "c": 6})
+        table.create_index('a', unique=True)
+        rec0, rec1 = table
+        self.assertEqual({"a": 1, "b": 2, "c": 3}, vars(rec0))
+        self.assertEqual(lt.default_row_class, type(rec0))
+        self.assertEqual(1, getattr(rec0, "a"))
+
+        # insert a nested dict
+        table.clear()
+        table.insert({"a": 1, "b": 2, "c": 3, "d": {"x": 100, "y": 200}})
+        table.insert({"a": 4, "b": 5, "c": 6, "d": {"x": 101, "y": 201}})
+        rec0, rec1 = table
+        self.assertEqual(100, rec0.d.x)
+        self.assertEqual(101, rec1.d.x)
+
     def test_where_equals(self):
         test_size = 10
         table = make_test_table(self.make_data_object, test_size)
@@ -619,6 +638,34 @@ class TableListTests:
         t1_stats = self.t1.stats()
         self.assertEqual(self.test_size ** num_fields - 1, t1_stats.by.name["a"].count)
 
+    def test_splitby(self):
+        self._test_init()
+        is_odd = lambda rec: rec.a % 2
+        evens, odds = self.t1.splitby(is_odd)
+        self.assertEqual(len(odds) + len(evens), len(self.t1))
+        self.assertEqual(len(odds), len(self.t1.where(is_odd)))
+
+        even_evens, odd_evens = evens.splitby(is_odd)
+        self.assertEqual(0, len(odd_evens))
+        self.assertEqual(len(even_evens), len(evens))
+
+        # make sure indexes are preserved
+        self.t1.create_index("a")
+        evens, odds = self.t1.splitby(is_odd)
+        self.assertEqual(self.t1.info()["indexes"], evens.info()["indexes"])
+
+        # test passing an attribute as a key
+        zeros, non_zeros = self.t1.splitby("a")
+        self.assertTrue(all(rec.a == 0 for rec in zeros))
+        self.assertTrue(all(rec.a != 0 for rec in non_zeros))
+
+        # test using predicate that does not always return 0 or 1
+        is_not_multiple_of_3 = lambda rec: rec.a % 3
+        mults_of_3, non_mults_of_3 = self.t1.splitby(is_not_multiple_of_3)
+        print(list(non_mults_of_3.all.a))
+        print(list(mults_of_3.all.a))
+
+
 class TableListTests_DataObjects(unittest.TestCase, TableListTests, UsingDataObjects):
     pass
 
